@@ -1,4 +1,4 @@
-CodeMirrorConfig.stylesheet = "python_field/css/pythoncolors.css";
+CodeMirrorConfig.stylesheet = "/python_field/css/pythoncolors.css";
 CodeMirrorConfig.path = "/python_field/js/";
 CodeMirrorConfig.parserfile = "parsepython.js";
 CodeMirrorConfig.height = "dynamic";
